@@ -1,5 +1,5 @@
 # This exports package resources so that anyone can use in their own projects.
-__all__ = ['StarterPkg', 'ConfigParser']
+__all__ = ['StarterPkg', 'ConfigLoader']
 
 from .starterpkg import *
 from .utils.configloader import *
\ No newline at end of file
