@@ -1,9 +1,9 @@
 #!/usr/bin/python3 -B
 from .starterpkg import StarterPkg
-from .utils.configloader import ConfigParser
+from .utils.configloader import ConfigLoader
 
 def main():
-	configparser = ConfigParser()
+	configparser = ConfigLoader()
 	starterpkg = StarterPkg(configparser)
 	starterpkg.run()
 
